@@ -1,7 +1,7 @@
 %%--------------------------------------------------------------------
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 2010-2017. All Rights Reserved.
+%% Copyright Ericsson AB 2010-2018. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -660,7 +660,7 @@ decrypt_config_file(EncryptFileName, TargetFileName, {key,Key}) ->
 get_crypt_key_from_file(File) ->
     case file:read_file(File) of
 	{ok,Bin} ->
-	    case catch string:tokens(binary_to_list(Bin), [$\n,$\r]) of
+	    case catch string:lexemes(binary_to_list(Bin), [$\n, [$\r,$\n]]) of
 		[Key] ->
 		    Key;
 		_ ->
@@ -694,7 +694,7 @@ get_crypt_key_from_file() ->
 	noent ->
 	    Result;
 	_ ->
-	    case catch string:tokens(binary_to_list(Result), [$\n,$\r]) of
+	    case catch string:lexemes(binary_to_list(Result), [$\n, [$\r,$\n]]) of
 		[Key] ->
 		    io:format("~nCrypt key file: ~ts~n", [FullName]),
 		    Key;
